/*
   FioVe IR Temp Meter -- Terminal Connection
   Sends temperature readings to Serial port
   see www.pfod.com.au for other projects

   (c)2013 Forward Computing and Control Pty. Ltd.
   This code may be freely used for both private and commerical use.
   Provide this copyright is maintained.

   NOTE: This sketch uses Interrupt 1
   and pins D2,D3,D4

*/

#include "pfodIRTemp.h"

static const byte PIN_DATA    = 2;
static const byte PIN_CLOCK   = 3;
static const byte PIN_ACQUIRE = 4;
static const byte CLOCK_INTERRUPT = 0; // D3 is connected to INT0 on FioV3

pfodIRTemp irTemp(PIN_DATA, PIN_CLOCK, PIN_ACQUIRE, CLOCK_INTERRUPT); // construct class to handle sensor

bool fahrenheit = false; // set to true for Fahrenheit instead of Celsius
void setup() {
  Serial.begin(9600);
  //Serial1.begin(9600); this line kills it
  for (int i = 5; i > 0; i--) { // wait a little while on startup, makes re-programming more reliable on FioV3
    delay(1000);
    Serial.print(i);
    Serial.print(F(" "));
  }
  Serial.println();
}

void loop() {
  irTemp.triggerSensor();
  int reading = irTemp.getIRTemperature();
  if (reading != pfodIRTemp::NO_DATA) {  // have a reading
    Serial.print(millis() / 1000.0); // output secs since restart
    Serial.print(F(",Sec,"));  // csv comma separator
    if (reading <  pfodIRTemp::NO_DATA) {
      if (reading == pfodIRTemp::INVALID_DATA) {
        Serial.println(F(" ,Invalid Reading"));
      } else {
        Serial.println(F(" ,Sensor Not Responding"));
      }
    } else {
      if (fahrenheit) {
        Serial.print(irTemp.convertToFahrenheit(reading));
        Serial.println(F(",F"));
      } else {
        Serial.print(irTemp.convertToCelsius(reading));
        Serial.println(F(",C"));
      }
    }
  }
}
